self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "581dc28f32dbfb5577ecd913f71ad5c5",
    "url": "./index.html"
  },
  {
    "revision": "17b94817f17767deddf8",
    "url": "./static/js/2.e26207c1.chunk.js"
  },
  {
    "revision": "3dc2da520b7611f998bec3f8b32ee24e",
    "url": "./static/js/2.e26207c1.chunk.js.LICENSE.txt"
  },
  {
    "revision": "19e383ff5e57b573e66b",
    "url": "./static/js/main.72bb61ad.chunk.js"
  },
  {
    "revision": "4e0e34f265fae8f33b01b27ae29d9d6f",
    "url": "./static/js/main.72bb61ad.chunk.js.LICENSE.txt"
  },
  {
    "revision": "90d19ed412daf6619dd4",
    "url": "./static/js/runtime-main.0ec16bce.js"
  }
]);